@@ -1,6 +1,6 @@
 package Firebase;
 {
-  $Firebase::VERSION = '0.0201';
+  $Firebase::VERSION = '0.0202';
 }
 
 use Moo;
@@ -30,6 +30,11 @@ has authobj        => (
     },
 );
 
+has debug => (
+    is          => 'rw',
+    default     => sub { '' },
+);
+
 has agent => (
     is          => 'ro',
     required    => 0,
@@ -71,6 +76,7 @@ sub process_request {
 
 sub process_response {
     my ($self, $response) = @_;
+    $self->debug($response->header('X-Firebase-Auth-Debug'));
     if ($response->is_success) {
         if ($response->decoded_content eq 'null') {
             return undef;
@@ -95,7 +101,7 @@ Firebase - An interface to firebase.com.
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -186,6 +192,14 @@ The path where the info is that you want deleted.
 =back
 
 
+
+=head2 debug
+
+If C<debug> has been set to a true value in C<Firebase::Auth>, this will return the debug message returned with the previous response.
+
+
+
+
 =head2 create_uri
 
 Creates a URI to a firebase data segment. You almost certainly want to use C<get>, C<put> or C<delete> instead.
